Enpoints
--------

.. note::
    This section document what you can call directly when you use PyFunceble as an imported module.

.. automodule:: PyFunceble
   :members:
   :exclude-members: stay_safe